.. _dispersion:

****************************************
Dispersion (`baseband_tasks.dispersion`)
****************************************

`~baseband_tasks.dispersion` uses the :ref:`dispersion measure <dm>` to correct
for the frequency-dependent slowing of radio signals passing through plasma.

.. _dispersion_api:

Reference/API
=============

.. automodapi:: baseband_tasks.dispersion
   :no-inherited-members:
